<?php

namespace Drupal\nodeauthorblock\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\field\Entity\FieldConfig;


/**
 * Provive 'Node author information' block
 *
 * @Block(
 *   id = "node_author_block",
 *   admin_label = @Translation("Node author information"),
 * )
 */
class NodeAuthorBlock extends BlockBase {

	/**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['label_display' => FALSE];
  }

	/**
	 * {@inheritdoc}
	 */
	public function build() {

		//check if we are viewing a node page
		$node = \Drupal::routeMatch()->getParameter('node');

		if ($node instanceof \Drupal\node\NodeInterface) {

			//make sure we actually got a node
			if (!$node || !is_object($node)) {
				// Logs an error
				\Drupal::logger('nodeauthorblock')->notice('@type: Block failed to get proper node %title.',
        array(
            '@type' => $this->entity->bundle(),
            '%title' => $this->entity->label(),
        ));
        return;
			}

			//load node author
			$uid = $node->getOwnerId();
			$account = user_load($uid);

			//image
			$field = \Drupal\field\Entity\FieldConfig::loadByName('user', 'user', 'user_picture');
			$default_image = $field->getSetting('default_image');
			//make sure to set image default for user account
      if ($default_image['uuid']) {
        $file = \Drupal::entityManager()->loadEntityByUuid('file', $default_image['uuid']);
        $default_uri = file_create_url($file->getFileUri());
      }
			$imageUri = !$account->user_picture->isEmpty() ? $account->user_picture->entity->getFileUri() : $default_uri;

			$markup_image = array (
    		'#theme' => 'image_style',
    		'#style_name' => 'node_author_thumbnail',
    		'#uri' => $imageUri,
			);
			
			$user_image = render($markup_image);

			//username
			$username = $account->get('name')->value;

			//date created
			$created = date('M d, Y', $node->get('created')->value);

			//pass variables to template file
			$renderable = [
      	'#theme' => 'node_author_block',
      	'#user_image' => $user_image,
      	'#username' => $username,
      	'#created' => $created,
      	'#attached' => [
        	'library' => [
          	'nodeauthorblock/nab_css',
        	],
      	],
    	];

    	return $renderable;
		}
	}


	// /**
	//  * {@inheritdoc}
	//  */
	// public function getCacheMaxAge() {
	// 	return 0;
	// }

}